==> igniteui-angular-core-17.3.0.tgz: package/esm2015/lib/RadialGaugeRangeDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { RadialGaugeRangeDescription } from "./RadialGaugeRangeDescription";
/**
 * @hidden
 */
export let RadialGaugeRangeDescriptionMetadata = /*@__PURE__*/ (() => {
    class RadialGaugeRangeDescriptionMetadata extends Base {
        static b(a) {
            if (RadialGaugeRangeDescriptionMetadata.a == null) {
                RadialGaugeRangeDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                RadialGaugeRangeDescriptionMetadata.c(RadialGaugeRangeDescriptionMetadata.a);
            }
            if (a.k(RadialGaugeRangeDescriptionMetadata.a)) {
                return;
            }
            a.ab(RadialGaugeRangeDescriptionMetadata.a);
        }
        static c(a) {
            a.item("Name", "String");
            a.item("Brush", "Brush");
            a.item("Outline", "Brush");
            a.item("StartValue", "Number:double");
            a.item("EndValue", "Number:double");
            a.item("InnerStartExtent", "Number:double");
            a.item("InnerEndExtent", "Number:double");
            a.item("OuterStartExtent", "Number:double");
            a.item("OuterEndExtent", "Number:double");
            a.item("StrokeThickness", "Number:double");
        }
        static d(a) {
            RadialGaugeRangeDescriptionMetadata.b(a);
            a.ad("RadialGaugeRange", () => new RadialGaugeRangeDescription());
            a.ac("RadialGaugeRange", RadialGaugeRangeDescriptionMetadata.a);
        }
    }
    RadialGaugeRangeDescriptionMetadata.$t = markType(RadialGaugeRangeDescriptionMetadata, 'RadialGaugeRangeDescriptionMetadata');
    RadialGaugeRangeDescriptionMetadata.a = null;
    return RadialGaugeRangeDescriptionMetadata;
})();

==> igniteui-angular-core-20.0.0.tgz: package/esm2015/lib/RadialGaugeRangeDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { RadialGaugeRangeDescription } from "./RadialGaugeRangeDescription";
/**
 * @hidden
 */
export let RadialGaugeRangeDescriptionMetadata = /*@__PURE__*/ (() => {
    class RadialGaugeRangeDescriptionMetadata extends Base {
        static b(a) {
            if (RadialGaugeRangeDescriptionMetadata.a == null) {
                RadialGaugeRangeDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                RadialGaugeRangeDescriptionMetadata.c(RadialGaugeRangeDescriptionMetadata.a);
            }
            if (a.k(RadialGaugeRangeDescriptionMetadata.a)) {
                return;
            }
            a.ac(RadialGaugeRangeDescriptionMetadata.a);
        }
        static c(a) {
            a.item("Name", "String");
            a.item("Brush", "Brush");
            a.item("Outline", "Brush");
            a.item("StartValue", "Number:double");
            a.item("EndValue", "Number:double");
            a.item("InnerStartExtent", "Number:double");
            a.item("InnerEndExtent", "Number:double");
            a.item("OuterStartExtent", "Number:double");
            a.item("OuterEndExtent", "Number:double");
            a.item("StrokeThickness", "Number:double");
        }
        static d(a) {
            RadialGaugeRangeDescriptionMetadata.b(a);
            a.ae("RadialGaugeRange", () => new RadialGaugeRangeDescription());
            a.ad("RadialGaugeRange", RadialGaugeRangeDescriptionMetadata.a);
        }
    }
    RadialGaugeRangeDescriptionMetadata.$t = markType(RadialGaugeRangeDescriptionMetadata, 'RadialGaugeRangeDescriptionMetadata');
    RadialGaugeRangeDescriptionMetadata.a = null;
    return RadialGaugeRangeDescriptionMetadata;
})();
